import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="triqt",
    version="1.0.1",
    description="Run the Qt event loop from within the Trio event loop",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/henry232323/triqt",
    author="henry232323",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
	"Programming Language :: Python :: 3.9",
    ],
    packages=[],
    include_package_data=True,
    install_requires=["trio"],
	py_modules=["triqt"],
)
